kenchi\.outlier\_detection package
==================================

Submodules
----------

.. toctree::

   kenchi.outlier_detection.empirical_distns
   kenchi.outlier_detection.gaussian_distns
   kenchi.outlier_detection.k_means
   kenchi.outlier_detection.mixture_distns
   kenchi.outlier_detection.vmf_distns

Module contents
---------------

.. automodule:: kenchi.outlier_detection
    :members:
    :undoc-members:
    :show-inheritance:
